cmoncrawl.processor.pipeline.router.Router.\_\_init\_\_
=======================================================

.. currentmodule:: cmoncrawl.processor.pipeline.router

.. automethod:: Router.__init__